@@ -414,14 +414,9 @@ void KmagApp::readOptions()
 }
 
 bool KmagApp::queryClose()
-{
-  return (true);
-}
-
-bool KmagApp::queryExit()
 {
   saveOptions();
-  return true;
+  return (true);
 }
 
 /**
